@@ -1,15 +1,18 @@
 from lbmpy.methods.creationfunctions import (
     create_mrt_orthogonal, create_mrt_raw, create_srt, create_trt, create_trt_kbc,
     create_trt_with_magic_number, create_with_continuous_maxwellian_eq_moments,
-    create_with_discrete_maxwellian_eq_moments, mrt_orthogonal_modes_literature)
-from lbmpy.methods.momentbased import (
-    AbstractConservedQuantityComputation, AbstractLbMethod, MomentBasedLbMethod, RelaxationInfo)
+    create_with_discrete_maxwellian_eq_moments, mrt_orthogonal_modes_literature,
+    create_centered_cumulant_model, create_with_default_polynomial_cumulants)
+
+from lbmpy.methods.abstractlbmethod import AbstractLbMethod, RelaxationInfo
+from lbmpy.methods.conservedquantitycomputation import AbstractConservedQuantityComputation
 
 from .conservedquantitycomputation import DensityVelocityComputation
 
 __all__ = ['RelaxationInfo', 'AbstractLbMethod',
-           'AbstractConservedQuantityComputation', 'DensityVelocityComputation', 'MomentBasedLbMethod',
+           'AbstractConservedQuantityComputation', 'DensityVelocityComputation',
            'create_srt', 'create_trt', 'create_trt_with_magic_number', 'create_trt_kbc',
            'create_mrt_orthogonal', 'create_mrt_raw',
            'create_with_continuous_maxwellian_eq_moments', 'create_with_discrete_maxwellian_eq_moments',
-           'mrt_orthogonal_modes_literature']
+           'mrt_orthogonal_modes_literature', 'create_centered_cumulant_model',
+           'create_with_default_polynomial_cumulants']
