@@ -3,7 +3,7 @@ import sympy as sp
 from lbmpy.innerloopsplit import create_lbm_split_groups
 from lbmpy.methods.momentbased.momentbasedmethod import MomentBasedLbMethod
 from lbmpy.methods.centeredcumulant import CenteredCumulantBasedLbMethod
-from lbmpy.methods.centeredcumulant.simplification import insert_aliases, insert_zeros
+from lbmpy.methods.centeredcumulant.simplification import insert_aliases, insert_zeros, insert_constants
 from lbmpy.methods.momentbased.momentbasedsimplifications import (
     factor_density_after_factoring_relaxation_times, factor_relaxation_rates,
     replace_common_quadratic_and_constant_term, replace_density_and_velocity, replace_second_order_velocity_products)
@@ -36,5 +36,6 @@ def create_simplification_strategy(lb_method, split_inner_loop=False):
     elif isinstance(lb_method, CenteredCumulantBasedLbMethod):
         s.add(insert_zeros)
         s.add(insert_aliases)
+        s.add(insert_constants)
         s.add(lambda ac: ac.new_without_unused_subexpressions())
     return s
